Class: Aws::AugmentedAIRuntime::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::AugmentedAIRuntime::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-augmentedairuntime/client.rb,
sig/client.rbs
Overview
An API client for AugmentedAIRuntime. To construct a client, you need to configure a :region and :credentials.
client = Aws::AugmentedAIRuntime::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _DeleteHumanLoopResponseSuccess, _DescribeHumanLoopResponseSuccess, _ListHumanLoopsResponseSuccess, _StartHumanLoopResponseSuccess, _StopHumanLoopResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#delete_human_loop(params = {}) ⇒ Struct
Deletes the specified human loop for a flow definition.
-
#describe_human_loop(params = {}) ⇒ Types::DescribeHumanLoopResponse
Returns information about the specified human loop.
-
#list_human_loops(params = {}) ⇒ Types::ListHumanLoopsResponse
Returns information about human loops, given the specified parameters.
-
#start_human_loop(params = {}) ⇒ Types::StartHumanLoopResponse
Starts a human loop, provided that at least one activation condition is met.
-
#stop_human_loop(params = {}) ⇒ Struct
Stops the specified human loop.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-augmentedairuntime/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
711 712 713 |
# File 'lib/aws-sdk-augmentedairuntime/client.rb', line 711 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
714 715 716 |
# File 'lib/aws-sdk-augmentedairuntime/client.rb', line 714 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 |
# File 'lib/aws-sdk-augmentedairuntime/client.rb', line 684 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::AugmentedAIRuntime') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-augmentedairuntime' context[:gem_version] = '1.71.0' Seahorse::Client::Request.new(handlers, context) end |
#delete_human_loop(params = {}) ⇒ Struct
Deletes the specified human loop for a flow definition.
If the human loop was deleted, this operation will return a
ResourceNotFoundException.
85 |
# File 'sig/client.rbs', line 85
def delete_human_loop: (
|
#describe_human_loop(params = {}) ⇒ Types::DescribeHumanLoopResponse
Returns information about the specified human loop. If the human loop
was deleted, this operation will return a ResourceNotFoundException
error.
102 |
# File 'sig/client.rbs', line 102
def describe_human_loop: (
|
#list_human_loops(params = {}) ⇒ Types::ListHumanLoopsResponse
Returns information about human loops, given the specified parameters. If a human loop was deleted, it will not be included.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
113 |
# File 'sig/client.rbs', line 113
def list_human_loops: (
|
#start_human_loop(params = {}) ⇒ Types::StartHumanLoopResponse
Starts a human loop, provided that at least one activation condition is met.
128 |
# File 'sig/client.rbs', line 128
def start_human_loop: (
|
#stop_human_loop(params = {}) ⇒ Struct
Stops the specified human loop.
144 |
# File 'sig/client.rbs', line 144
def stop_human_loop: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
704 705 706 |
# File 'lib/aws-sdk-augmentedairuntime/client.rb', line 704 def waiter_names [] end |