Class: Aws::AugmentedAIRuntime::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::AugmentedAIRuntime::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-augmentedairuntime/client.rb
Overview
An API client for AugmentedAIRuntime. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::AugmentedAIRuntime::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#delete_human_loop(params = {}) ⇒ Struct
Deletes the specified human loop for a flow definition.
-
#describe_human_loop(params = {}) ⇒ Types::DescribeHumanLoopResponse
Returns information about the specified human loop.
-
#list_human_loops(params = {}) ⇒ Types::ListHumanLoopsResponse
Returns information about human loops, given the specified parameters.
-
#start_human_loop(params = {}) ⇒ Types::StartHumanLoopResponse
Starts a human loop, provided that at least one activation condition is met.
-
#stop_human_loop(params = {}) ⇒ Struct
Stops the specified human loop.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
473 474 475 |
# File 'lib/aws-sdk-augmentedairuntime/client.rb', line 473 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
713 714 715 |
# File 'lib/aws-sdk-augmentedairuntime/client.rb', line 713 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
716 717 718 |
# File 'lib/aws-sdk-augmentedairuntime/client.rb', line 716 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 |
# File 'lib/aws-sdk-augmentedairuntime/client.rb', line 686 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::AugmentedAIRuntime') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-augmentedairuntime' context[:gem_version] = '1.65.0' Seahorse::Client::Request.new(handlers, context) end |
#delete_human_loop(params = {}) ⇒ Struct
Deletes the specified human loop for a flow definition.
If the human loop was deleted, this operation will return a ‘ResourceNotFoundException`.
499 500 501 502 |
# File 'lib/aws-sdk-augmentedairuntime/client.rb', line 499 def delete_human_loop(params = {}, = {}) req = build_request(:delete_human_loop, params) req.send_request() end |
#describe_human_loop(params = {}) ⇒ Types::DescribeHumanLoopResponse
Returns information about the specified human loop. If the human loop was deleted, this operation will return a ‘ResourceNotFoundException` error.
543 544 545 546 |
# File 'lib/aws-sdk-augmentedairuntime/client.rb', line 543 def describe_human_loop(params = {}, = {}) req = build_request(:describe_human_loop, params) req.send_request() end |
#list_human_loops(params = {}) ⇒ Types::ListHumanLoopsResponse
Returns information about human loops, given the specified parameters. If a human loop was deleted, it will not be included.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
607 608 609 610 |
# File 'lib/aws-sdk-augmentedairuntime/client.rb', line 607 def list_human_loops(params = {}, = {}) req = build_request(:list_human_loops, params) req.send_request() end |
#start_human_loop(params = {}) ⇒ Types::StartHumanLoopResponse
Starts a human loop, provided that at least one activation condition is met.
655 656 657 658 |
# File 'lib/aws-sdk-augmentedairuntime/client.rb', line 655 def start_human_loop(params = {}, = {}) req = build_request(:start_human_loop, params) req.send_request() end |
#stop_human_loop(params = {}) ⇒ Struct
Stops the specified human loop.
677 678 679 680 |
# File 'lib/aws-sdk-augmentedairuntime/client.rb', line 677 def stop_human_loop(params = {}, = {}) req = build_request(:stop_human_loop, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
706 707 708 |
# File 'lib/aws-sdk-augmentedairuntime/client.rb', line 706 def waiter_names [] end |